# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.constants import Basins
from earthdiagnostics.ocean.areamoc import AreaMoc
from mock import Mock


class TestAreaMoc(TestCase):
    
    def setUp(self):
        self.data_manager = Mock()
        self.diags = Mock()

        self.box = Box()
        self.box.min_lat = 0
        self.box.max_lat = 0
        self.box.min_depth = 0
        self.box.max_depth = 0

        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))
        self.psi = AreaMoc(self.data_manager, '20000101', 1, 1, Basins.Antarctic, self.box)

    def test_generate_jobs(self):
        jobs = AreaMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], AreaMoc(self.data_manager, '20010101', 0, 0, Basins.Global, self.box))
        self.assertEqual(jobs[1], AreaMoc(self.data_manager, '20010101', 0, 1, Basins.Global, self.box))

        jobs = AreaMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', 'atl'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], AreaMoc(self.data_manager, '20010101', 0, 0, Basins.Atlantic, self.box))
        self.assertEqual(jobs[1], AreaMoc(self.data_manager, '20010101', 0, 1, Basins.Atlantic, self.box))

        with self.assertRaises(Exception):
            AreaMoc.generate_jobs(self.diags, ['psi'])
        with self.assertRaises(Exception):
            AreaMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.psi), 'Area MOC Startdate: 20000101 Member: 1 Chunk: 1 Box: 0N0')
