# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.ocean.averagesection import AverageSection
from mock import Mock

from earthdiagnostics.variable import Domains, Domain


class TestAverageSection(TestCase):

    def setUp(self):
        self.data_manager = Mock()
        self.diags = Mock()

        self.box = Box()
        self.box.min_lat = 0
        self.box.max_lat = 0
        self.box.min_lon = 0
        self.box.max_lon = 0

        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))
        self.psi = AverageSection(self.data_manager, '20000101', 1, 1, Domains.ocean, 'var', self.box)

    def test_generate_jobs(self):
        jobs = AverageSection.generate_jobs(self.diags, ['psi', 'var', '0', '0', '0', '0'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], AverageSection(self.data_manager, '20010101', 0, 0, Domains.ocean, 'var', self.box))
        self.assertEqual(jobs[1], AverageSection(self.data_manager, '20010101', 0, 1, Domains.ocean, 'var', self.box))

        jobs = AverageSection.generate_jobs(self.diags, ['psi', 'var', '0', '0', '0', '0', 'ocean'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], AverageSection(self.data_manager, '20010101', 0, 0, Domains.ocean, 'var', self.box))
        self.assertEqual(jobs[1], AverageSection(self.data_manager, '20010101', 0, 1, Domains.ocean, 'var', self.box))

        with self.assertRaises(Exception):
            AverageSection.generate_jobs(self.diags, ['psi'])
        with self.assertRaises(Exception):
            AverageSection.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.psi), 'Average section Startdate: 20000101 Member: 1 Chunk: 1 Box: 0N0E '
                                         'Variable: ocean:var')
