# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.constants import Basins
from earthdiagnostics.ocean.maxmoc import MaxMoc
from mock import Mock


class TestMaxMoc(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.box = Box()
        self.box.min_lat = 0
        self.box.max_lat = 0
        self.box.min_depth = 0
        self.box.max_depth = 0

        self.maxmoc = MaxMoc(self.data_manager, '20000101', 1, 2000, Basins.Global, self.box)

    def test_generate_jobs(self):
        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.startdates = ('20010101',)
        self.diags.members = (0,)
        self.diags.config.experiment.get_full_years.return_value = (2000, 2001)

        jobs = MaxMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MaxMoc(self.data_manager, '20010101', 0, 2000, Basins.Global, self.box))
        self.assertEqual(jobs[1], MaxMoc(self.data_manager, '20010101', 0, 2001, Basins.Global, self.box))

        jobs = MaxMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', 'atl'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MaxMoc(self.data_manager, '20010101', 0, 2000, Basins.Atlantic, self.box))
        self.assertEqual(jobs[1], MaxMoc(self.data_manager, '20010101', 0, 2001, Basins.Atlantic, self.box))

        self.diags.config.experiment.get_full_years.return_value = list()
        jobs = MaxMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0'])
        self.assertEqual(len(jobs), 0)

        with self.assertRaises(Exception):
            MaxMoc.generate_jobs(self.diags, ['psi'])

        with self.assertRaises(Exception):
            MaxMoc.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.maxmoc), 'Max moc Startdate: 20000101 Member: 1 Year: 2000 '
                                            'Box: 0N0 Basin: Global_Ocean')
