# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.general.monthlymean import MonthlyMean
from mock import Mock

from earthdiagnostics.variable import Domains


class TestMonthlyMean(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.box = Box()
        self.box.min_depth = 0
        self.box.max_depth = 100

        self.mixed = MonthlyMean(self.data_manager, '20000101', 1, 1, Domains.ocean, 'var', 'freq', '')

    def test_generate_jobs(self):

        jobs = MonthlyMean.generate_jobs(self.diags, ['psi', 'var', 'ocean'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyMean(self.data_manager, '20010101', 0, 0, Domains.ocean, 'var', 'day', ''))
        self.assertEqual(jobs[1], MonthlyMean(self.data_manager, '20010101', 0, 1, Domains.ocean, 'var', 'day', ''))

        jobs = MonthlyMean.generate_jobs(self.diags, ['psi', 'var', 'atmos', 'freq'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyMean(self.data_manager, '20010101', 0, 0, Domains.atmos, 'var', 'freq', ''))
        self.assertEqual(jobs[1], MonthlyMean(self.data_manager, '20010101', 0, 1, Domains.atmos, 'var', 'freq', ''))

        jobs = MonthlyMean.generate_jobs(self.diags, ['psi', 'var', 'seaice', 'freq', 'grid'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyMean(self.data_manager, '20010101', 0, 0, Domains.seaIce, 'var', 'freq',
                                              'grid'))
        self.assertEqual(jobs[1], MonthlyMean(self.data_manager, '20010101', 0, 1, Domains.seaIce, 'var', 'freq',
                                              'grid'))

        with self.assertRaises(Exception):
            MonthlyMean.generate_jobs(self.diags, ['psi'])

        with self.assertRaises(Exception):
            MonthlyMean.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.mixed), 'Calculate monthly mean Startdate: 20000101 Member: 1 Chunk: 1 '
                                           'Variable: ocean:var')
