# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.general.rewrite import Rewrite
from mock import Mock

from earthdiagnostics.variable import Domains


class TestRewrite(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.box = Box()
        self.box.min_depth = 0
        self.box.max_depth = 100

        self.mixed = Rewrite(self.data_manager, '20000101', 1, 1, Domains.atmos, 'var', 'grid')

    def test_generate_jobs(self):

        jobs = Rewrite.generate_jobs(self.diags, ['psi', 'var', 'atmos'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], Rewrite(self.data_manager, '20010101', 0, 0, Domains.atmos, 'var', 'original'))
        self.assertEqual(jobs[1], Rewrite(self.data_manager, '20010101', 0, 1, Domains.atmos, 'var', 'original'))

        jobs = Rewrite.generate_jobs(self.diags, ['psi', 'var', 'ocean', 'grid'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], Rewrite(self.data_manager, '20010101', 0, 0, Domains.ocean, 'var', 'grid'))
        self.assertEqual(jobs[1], Rewrite(self.data_manager, '20010101', 0, 1, Domains.ocean, 'var', 'grid'))

        with self.assertRaises(Exception):
            Rewrite.generate_jobs(self.diags, ['psi'])

        with self.assertRaises(Exception):
            Rewrite.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.mixed), 'Rewrite output Startdate: 20000101 Member: 1 Chunk: 1 '
                                           'Variable: atmos:var Grid: grid')
