# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.ocean.verticalmeanmeters import VerticalMeanMeters
from mock import Mock


class TestVerticalMeanMeters(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.box = Box(True)
        self.box.min_depth = 0
        self.box.max_depth = 100

        self.mixed = VerticalMeanMeters(self.data_manager, '20000101', 1, 1, 'var', self.box)

    def test_generate_jobs(self):
        jobs = VerticalMeanMeters.generate_jobs(self.diags, ['psi', 'var', '0', '100'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], VerticalMeanMeters(self.data_manager, '20010101', 0, 0, 'var', self.box))
        self.assertEqual(jobs[1], VerticalMeanMeters(self.data_manager, '20010101', 0, 1, 'var', self.box))

        jobs = VerticalMeanMeters.generate_jobs(self.diags, ['psi', 'var', '0'])
        box = Box(True)
        box.min_depth = 0
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], VerticalMeanMeters(self.data_manager, '20010101', 0, 0, 'var', box))
        self.assertEqual(jobs[1], VerticalMeanMeters(self.data_manager, '20010101', 0, 1, 'var', box))

        jobs = VerticalMeanMeters.generate_jobs(self.diags, ['psi', 'var'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], VerticalMeanMeters(self.data_manager, '20010101', 0, 0, 'var', Box(True)))
        self.assertEqual(jobs[1], VerticalMeanMeters(self.data_manager, '20010101', 0, 1, 'var', Box(True)))

        with self.assertRaises(Exception):
            VerticalMeanMeters.generate_jobs(self.diags, ['psi'])

        with self.assertRaises(Exception):
            VerticalMeanMeters.generate_jobs(self.diags, ['psi', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.mixed), 'Vertical mean meters Startdate: 20000101 Member: 1 Chunk: 1 Variable: var '
                                           'Box: 0m-100m')
